@@ -15,6 +15,7 @@ import (
 	v1 "github.com/icinga/icingadb/pkg/icingadb/v1"
 	"github.com/icinga/icingadb/pkg/icingaredis"
 	"github.com/icinga/icingadb/pkg/icingaredis/telemetry"
+	"github.com/icinga/icingadb/pkg/notifications"
 	"github.com/okzk/sdnotify"
 	"github.com/pkg/errors"
 	"go.uber.org/zap"
@@ -30,7 +31,7 @@ import (
 const (
 	ExitSuccess                = 0
 	ExitFailure                = 1
-	expectedRedisSchemaVersion = "5"
+	expectedRedisSchemaVersion = "6"
 )
 
 func main() {
@@ -56,14 +57,14 @@ func run() int {
 
 	db, err := cmd.Database(logs.GetChildLogger("database"))
 	if err != nil {
-		logger.Fatalf("%+v", errors.Wrap(err, "can't create database connection pool from config"))
+		logger.Fatalw("Can't create database connection pool from config", zap.Error(err))
 	}
 	defer func() { _ = db.Close() }()
 	{
 		logger.Infof("Connecting to database at '%s'", db.GetAddr())
 		err := db.Ping()
 		if err != nil {
-			logger.Fatalf("%+v", errors.Wrap(err, "can't connect to database"))
+			logger.Fatalw("Can't connect to database", zap.Error(err))
 		}
 	}
 
@@ -74,9 +75,19 @@ func run() int {
 		}
 
 		logger.Info("Starting database schema auto import")
-		if err := icingadb.ImportSchema(context.Background(), db, cmd.Flags.DatabaseSchemaDir); err != nil {
-			logger.Fatalf("%+v", errors.Wrap(err, "can't import database schema"))
+
+		db, err := cmd.Database(logs.GetChildLogger("database"))
+		if err != nil {
+			logger.Fatalw("Can't create database connection pool from config", zap.Error(err))
 		}
+		db.SetMaxOpenConns(1)
+
+		if err := icingadb.ImportSchema(context.Background(), db, cmd.Flags.DatabaseSchemaDir); err != nil {
+			logger.Fatalw("Can't import database schema", zap.Error(err))
+		}
+
+		_ = db.Close()
+
 		logger.Info("The database schema was successfully imported")
 	case err != nil:
 		logger.Fatalf("%+v", err)
@@ -84,13 +95,13 @@ func run() int {
 
 	rc, err := cmd.Redis(logs.GetChildLogger("redis"))
 	if err != nil {
-		logger.Fatalf("%+v", errors.Wrap(err, "can't create Redis client from config"))
+		logger.Fatalw("Can't create Redis client from config", zap.Error(err))
 	}
 	{
 		logger.Infof("Connecting to Redis at '%s'", rc.GetAddr())
 		_, err := rc.Ping(context.Background()).Result()
 		if err != nil {
-			logger.Fatalf("%+v", errors.Wrap(err, "can't connect to Redis"))
+			logger.Fatalw("Can't create Redis client from config", zap.Error(err))
 		}
 	}
 
@@ -116,13 +127,13 @@ func run() int {
 	{
 		rc, err := cmd.Redis(logs.GetChildLogger("redis"))
 		if err != nil {
-			logger.Fatalf("%+v", errors.Wrap(err, "can't create Redis client from config"))
+			logger.Fatalw("Can't connect to Redis", zap.Error(err))
 		}
 		heartbeat = icingaredis.NewHeartbeat(ctx, rc, logs.GetChildLogger("heartbeat"))
 
 		db, err := cmd.Database(logs.GetChildLogger("database"))
 		if err != nil {
-			logger.Fatalf("%+v", errors.Wrap(err, "can't create database connection pool from config"))
+			logger.Fatalw("Can't create database connection pool from config", zap.Error(err))
 		}
 		defer func() { _ = db.Close() }()
 		db.SetMaxOpenConns(1)
@@ -158,13 +169,32 @@ func run() int {
 	sig := make(chan os.Signal, 1)
 	signal.Notify(sig, os.Interrupt, syscall.SIGTERM, syscall.SIGHUP)
 
-	go func() {
-		logger.Info("Starting history sync")
+	{
+		var extraStages map[string]history.StageFunc
+		if cfg := cmd.Config.Notifications; cfg.Url != "" {
+			logger.Info("Starting Icinga Notifications source")
 
-		if err := hs.Sync(ctx); err != nil && !utils.IsContextCanceled(err) {
-			logger.Fatalf("%+v", err)
+			notificationsSource, err := notifications.NewNotificationsClient(
+				ctx,
+				db,
+				rc,
+				logs.GetChildLogger("notifications"),
+				cfg)
+			if err != nil {
+				logger.Fatalw("Can't create Icinga Notifications client from config", zap.Error(err))
+			}
+
+			extraStages = notificationsSource.SyncExtraStages()
 		}
-	}()
+
+		go func() {
+			logger.Info("Starting history sync")
+
+			if err := hs.Sync(ctx, extraStages); err != nil && !utils.IsContextCanceled(err) {
+				logger.Fatalf("%+v", err)
+			}
+		}()
+	}
 
 	// Main loop
 	for {
@@ -220,8 +250,6 @@ func run() int {
 
 						logger.Info("Starting config sync")
 						for _, factory := range v1.ConfigFactories {
-							factory := factory
-
 							configInitSync.Add(1)
 							g.Go(func() error {
 								defer configInitSync.Done()
@@ -231,8 +259,6 @@ func run() int {
 						}
 						logger.Info("Starting initial state sync")
 						for _, factory := range v1.StateFactories {
-							factory := factory
-
 							stateInitSync.Add(1)
 							g.Go(func() error {
 								defer stateInitSync.Done()
@@ -339,16 +365,16 @@ func run() int {
 				cancelHactx()
 			case <-hactx.Done():
 				if ctx.Err() != nil {
-					logger.Fatalf("%+v", errors.New("main context closed unexpectedly"))
+					logger.Fatalw("Main context closed unexpectedly", zap.Error(ctx.Err()))
 				}
 				// Otherwise, there is nothing to do here, surrounding loop will terminate now.
 			case <-ha.Done():
 				if err := ha.Err(); err != nil {
-					logger.Fatalf("%+v", errors.Wrap(err, "HA exited with an error"))
+					logger.Fatalw("HA exited with an error", zap.Error(err))
 				} else if ctx.Err() == nil {
 					// ha is created as a single instance once. It should only exit if the main context is cancelled,
 					// otherwise there is no way to get Icinga DB back into a working state.
-					logger.Fatalf("%+v", errors.New("HA exited without an error but main context isn't cancelled"))
+					logger.Fatal("HA exited without an error but main context isn't cancelled")
 				}
 				cancelHactx()
 
