@@ -3,11 +3,11 @@ package icingadb
 import (
 	"context"
 	"fmt"
-	"github.com/icinga/icingadb/internal"
-	"github.com/icinga/icingadb/pkg/backoff"
-	"github.com/icinga/icingadb/pkg/com"
-	"github.com/icinga/icingadb/pkg/retry"
-	"github.com/icinga/icingadb/pkg/types"
+	"github.com/icinga/icinga-go-library/backoff"
+	"github.com/icinga/icinga-go-library/com"
+	"github.com/icinga/icinga-go-library/database"
+	"github.com/icinga/icinga-go-library/retry"
+	"github.com/icinga/icinga-go-library/types"
 	"time"
 )
 
@@ -18,37 +18,21 @@ type CleanupStmt struct {
 	Column string
 }
 
-// Build assembles the cleanup statement for the specified database driver with the given limit.
-func (stmt *CleanupStmt) Build(driverName string, limit uint64) string {
-	switch driverName {
-	case MySQL:
-		return fmt.Sprintf(`DELETE FROM %[1]s WHERE environment_id = :environment_id AND %[2]s < :time
-ORDER BY %[2]s LIMIT %[3]d`, stmt.Table, stmt.Column, limit)
-	case PostgreSQL:
-		return fmt.Sprintf(`WITH rows AS (
-SELECT %[1]s FROM %[2]s WHERE environment_id = :environment_id AND %[3]s < :time ORDER BY %[3]s LIMIT %[4]d
-)
-DELETE FROM %[2]s WHERE %[1]s IN (SELECT %[1]s FROM rows)`, stmt.PK, stmt.Table, stmt.Column, limit)
-	default:
-		panic(fmt.Sprintf("invalid database type %s", driverName))
-	}
-}
-
 // CleanupOlderThan deletes all rows with the specified statement that are older than the given time.
 // Deletes a maximum of as many rows per round as defined in count. Actually deleted rows will be passed to onSuccess.
 // Returns the total number of rows deleted.
-func (db *DB) CleanupOlderThan(
-	ctx context.Context, stmt CleanupStmt, envId types.Binary,
-	count uint64, olderThan time.Time, onSuccess ...OnSuccess[struct{}],
+func (stmt *CleanupStmt) CleanupOlderThan(
+	ctx context.Context, db *database.DB, envId types.Binary,
+	count uint64, olderThan time.Time, onSuccess ...database.OnSuccess[struct{}],
 ) (uint64, error) {
 	var counter com.Counter
 
-	q := db.Rebind(stmt.Build(db.DriverName(), count))
+	q := db.Rebind(stmt.build(db.DriverName(), count))
 
-	defer db.log(ctx, q, &counter).Stop()
+	defer db.Log(ctx, q, &counter).Stop()
 
 	for {
-		var rowsDeleted int64
+		var rowsDeleted uint64
 
 		err := retry.WithBackoff(
 			ctx,
@@ -58,22 +42,25 @@ func (db *DB) CleanupOlderThan(
 					Time:          types.UnixMilli(olderThan),
 				})
 				if err != nil {
-					return internal.CantPerformQuery(err, q)
+					return database.CantPerformQuery(err, q)
 				}
 
-				rowsDeleted, err = rs.RowsAffected()
+				i, err := rs.RowsAffected()
+				if err == nil && i >= 0 {
+					rowsDeleted = uint64(i)
+				}
 
 				return err
 			},
 			retry.Retryable,
-			backoff.NewExponentialWithJitter(1*time.Millisecond, 1*time.Second),
-			db.getDefaultRetrySettings(),
+			backoff.DefaultBackoff,
+			db.GetDefaultRetrySettings(),
 		)
 		if err != nil {
 			return 0, err
 		}
 
-		counter.Add(uint64(rowsDeleted))
+		counter.Add(rowsDeleted)
 
 		for _, onSuccess := range onSuccess {
 			if err := onSuccess(ctx, make([]struct{}, rowsDeleted)); err != nil {
@@ -81,7 +68,7 @@ func (db *DB) CleanupOlderThan(
 			}
 		}
 
-		if rowsDeleted < int64(count) {
+		if rowsDeleted < count {
 			break
 		}
 	}
@@ -89,6 +76,22 @@ func (db *DB) CleanupOlderThan(
 	return counter.Total(), nil
 }
 
+// build assembles the cleanup statement for the specified database driver with the given limit.
+func (stmt *CleanupStmt) build(driverName string, limit uint64) string {
+	switch driverName {
+	case database.MySQL:
+		return fmt.Sprintf(`DELETE FROM %[1]s WHERE environment_id = :environment_id AND %[2]s < :time LIMIT %[3]d`,
+			stmt.Table, stmt.Column, limit)
+	case database.PostgreSQL:
+		return fmt.Sprintf(`WITH rows AS (
+SELECT %[1]s FROM %[2]s WHERE environment_id = :environment_id AND %[3]s < :time LIMIT %[4]d
+)
+DELETE FROM %[2]s WHERE %[1]s IN (SELECT %[1]s FROM rows)`, stmt.PK, stmt.Table, stmt.Column, limit)
+	default:
+		panic(fmt.Sprintf("invalid database type %s", driverName))
+	}
+}
+
 type cleanupWhere struct {
 	EnvironmentId types.Binary
 	Time          types.UnixMilli
