@@ -129,9 +129,7 @@ func TestDelta(t *testing.T) {
 		nextId := uint64(1)
 		var wg sync.WaitGroup
 		for _, test := range tests {
-			test := test
 			for _, sendOrder := range sendOrders {
-				sendOrder := sendOrder
 				id := nextId
 				nextId++
 				// Log ID mapping to allow easier debugging in case of failures.
@@ -196,8 +194,9 @@ func testDeltaVerifyResult(t *testing.T, name string, expected map[uint64]uint64
 		idKey := testDeltaMakeIdOrChecksum(id).String()
 		if assert.Containsf(t, got, idKey, "%s: should contain %s", name, idKey) {
 			expectedChecksum := testDeltaMakeIdOrChecksum(checksum).String()
-			gotChecksum := got[idKey].(contracts.Checksumer).Checksum().String()
-			assert.Equalf(t, expectedChecksum, gotChecksum, "%s: %s should match checksum", name, idKey)
+			gotChecksum, ok := got[idKey].(contracts.Checksumer)
+			assert.True(t, ok, "got[idKey] does not implement contracts.Checksummer")
+			assert.Equalf(t, expectedChecksum, gotChecksum.Checksum().String(), "%s: %s should match checksum", name, idKey)
 			delete(got, idKey)
 		}
 	}
@@ -231,7 +230,7 @@ func benchmarkDelta(b *testing.B, numEntities uint64) {
 		binary.BigEndian.PutUint64(e.PropertiesChecksum, checksum)
 		return e
 	}
-	for i := uint64(0); i < numEntities; i++ {
+	for i := range numEntities {
 		// each iteration writes exactly one entity to each channel
 		var eActual, eDesired database.Entity
 		switch i % 3 {
