@@ -26,7 +26,7 @@ func CreateEntities(ctx context.Context, factoryFunc database.EntityFactoryFunc,
 
 		g, ctx := errgroup.WithContext(ctx)
 
-		for i := 0; i < concurrent; i++ {
+		for range concurrent {
 			g.Go(func() error {
 				for {
 					select {
@@ -77,7 +77,7 @@ func SetChecksums(ctx context.Context, entities <-chan database.Entity, checksum
 
 		g, ctx := errgroup.WithContext(ctx)
 
-		for i := 0; i < concurrent; i++ {
+		for range concurrent {
 			g.Go(func() error {
 				for {
 					select {
@@ -87,7 +87,15 @@ func SetChecksums(ctx context.Context, entities <-chan database.Entity, checksum
 						}
 
 						if checksumer, ok := checksums[entity.ID().String()]; ok {
-							entity.(contracts.Checksumer).SetChecksum(checksumer.(contracts.Checksumer).Checksum())
+							entity, entityOk := entity.(contracts.Checksumer)
+							if !entityOk {
+								return errors.New("entity does not implement contracts.Checksumer")
+							}
+							checksumer, checksumerOk := checksumer.(contracts.Checksumer)
+							if !checksumerOk {
+								return errors.New("checksumer does not implement contracts.Checksumer")
+							}
+							entity.SetChecksum(checksumer.Checksum())
 						} else {
 							return errors.Errorf("no checksum for %#v", entity)
 						}
